package cn.com.infosec.asn1.ess;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.IssuerSerial;

public class ESSCertID extends ASN1Encodable {
   private ASN1OctetString certHash;
   private IssuerSerial issuerSerial;

   public static ESSCertID getInstance(Object o) {
      if (o != null && !(o instanceof ESSCertID)) {
         if (o instanceof ASN1Sequence) {
            return new ESSCertID((ASN1Sequence)o);
         } else {
            throw new IllegalArgumentException("unknown object in 'ESSCertID' factory : " + o.getClass().getName() + ".");
         }
      } else {
         return (ESSCertID)o;
      }
   }

   public ESSCertID(ASN1Sequence seq) {
      if (seq.size() >= 1 && seq.size() <= 2) {
         this.certHash = ASN1OctetString.getInstance(seq.getObjectAt(0));
         if (seq.size() > 1) {
            this.issuerSerial = IssuerSerial.getInstance(seq.getObjectAt(1));
         }

      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public ESSCertID(byte[] hash) {
      ESSCertID var10000 = this;
      super();
      DEROctetString var2;
      var2 = new DEROctetString.<init>(hash);
      var10000.certHash = var2;
   }

   public ESSCertID(byte[] hash, IssuerSerial issuerSerial) {
      ESSCertID var10000 = this;
      ESSCertID var10001 = this;
      super();
      DEROctetString var3;
      var3 = new DEROctetString.<init>(hash);
      var10001.certHash = var3;
      var10000.issuerSerial = issuerSerial;
   }

   public byte[] getCertHash() {
      return this.certHash.getOctets();
   }

   public IssuerSerial getIssuerSerial() {
      return this.issuerSerial;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.certHash);
      IssuerSerial var2;
      if ((var2 = this.issuerSerial) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
